Index: src/compiler/ast-graph-builder.h |
diff --git a/src/compiler/ast-graph-builder.h b/src/compiler/ast-graph-builder.h |
index 17190bc8b7adad0612335c14cb2895fa654a5d4f..b2c6f4355d26fa75953ab61c6b46d1abe70bc7a3 100644 |
--- a/src/compiler/ast-graph-builder.h |
+++ b/src/compiler/ast-graph-builder.h |
@@ -265,8 +265,11 @@ class AstGraphBuilder : public AstVisitor { |
// Builder to create an array of rest parameters if used |
Node* BuildRestArgumentsArray(Variable* rest, int index); |
- // Builder that assigns to the .this_function internal variable if needed. |
- Node* BuildThisFunctionVar(Variable* this_function_var); |
+ // Builder that assigns to the {.this_function} internal variable if needed. |
+ Node* BuildThisFunctionVariable(Variable* this_function_var); |
+ |
+ // Builder that assigns to the {new.target} internal variable if needed. |
+ Node* BuildNewTargetVariable(Variable* new_target_var); |
// Builders for variable load and assignment. |
Node* BuildVariableAssignment(Variable* variable, Node* value, |